import { $get, $post, $postParam } from "@/plugins/axios";

// common-select
export const appTypeList = datas => {
  return $get("/api/admin/app/types", datas);
};
export const appDeployList = datas => {
  return $get("/api/admin/app/deploy_modes", datas);
};

// app-manage
export const appQuery = datas => {
  return $get("/api/admin/app/query", datas);
};
export const appInsertOrUpdate = datas => {
  if (datas.id) {
    return $post("/api/admin/app/update", datas);
  } else {
    return $post("/api/admin/app/insert", datas);
  }
};
export const appBindOrg = datas => {
  return $postParam("/api/admin/app/bind_org", datas);
};
export const appResetSecret = id => {
  return $postParam("/api/admin/app/reset_secret", { id });
};
export const appControlKeys = () => {
  return $get("/api/admin/app/control_keys", {});
};
export const appLicenseDownload = ({ appId, deviceId }) => {
  return $postParam(
    "/api/admin/app/license/download",
    { appId, deviceId },
    { responseType: "blob" }
  );
};
// app-devive manage
export const appDeviceList = appId => {
  return $postParam("/api/admin/app/device/list", { appId });
};
export const appDeviceInfo = deviceId => {
  return $postParam("/api/admin/app/device/info", { deviceId });
};
export const appDeviceSave = datas => {
  let formData = new FormData();
  Object.keys(datas).forEach(key => {
    formData.append(key, datas[key]);
  });
  return $post("/api/admin/app/device/save", formData);
};
export const appDeviceDelete = ({ appId, deviceId }) => {
  return $postParam("/api/admin/app/device/delete", { appId, deviceId });
};

// org-manage
export const orgTypesList = datas => {
  return $get("/api/admin/org/types", datas);
};
export const orgSubTypesList = datas => {
  return $get("/api/admin/org/sub_types", datas);
};
export const orgQuery = datas => {
  return $get("/api/admin/org/query", datas);
};
export const orgInsertOrUpdate = datas => {
  let formData = new FormData();
  Object.entries(datas).forEach(([key, val]) => {
    // if (val === null || val === "null" || val === "") return;

    if (key === "subTypes") {
      if (val.length) {
        val.forEach(type => formData.append("subTypes", type));
      } else {
        formData.append("subTypes", "");
      }
    } else {
      formData.append(key, datas[key]);
    }
  });

  if (datas.id) {
    return $post("/api/admin/org/update", formData);
  } else {
    return $post("/api/admin/org/insert", formData);
  }
};
// 启用/禁用
export const orgToggle = datas => {
  return $get("/api/admin/org/toggle", datas);
};

/**
 * @description 微信小程序查询
 * @params { string } id  // 应用ID
 * @params { string } nameStartWith  // 名称前缀
 * @params { string } pageNumber  // 页码
 * @params { string } pageSize  // 数量
 */
export const getWeChatAppList = data => {
  const params = Object.entries(data).reduce((p, [key, val]) => {
    if (val) {
      p[key] = val;
    }
    return p;
  }, {});
  return $post("/api/admin/wxapp/query", new URLSearchParams(params));
};

/**
 * @description 微信小程序新增
 * @params { string } id  // 应用ID
 * @params { string } name  // 名称
 * @params { string } secret  // 密钥
 */
export const insertWeChatApp = data => {
  return $post("/api/admin/wxapp/insert", new URLSearchParams(data));
};

/**
 * @description 微信小程序修改
 * @params { string } id  // 应用ID
 * @params { string } name  // 名称
 * @params { string } secret  // 密钥
 */
export const updateWeChatApp = data => {
  return $post("/api/admin/wxapp/update", new URLSearchParams(data));
};
